@@ -51,8 +51,10 @@ def version():
         - admin增加orm检索      # 2.4.7
         - simplrui的admin_class的基类改为`AjaxAdmin`
         - 修复Mixin后置导致的Guadian失效的bug     # 2.4.8
+        - 增加_ajax_return_qs_ls, 以便admin中的ajax方法返回qs_ls      # 2.4.9
+        - django.utils.get_field_names_by_model增加`field_attr`, 以便获取[name, verbose_name]
     """
-    v = "2.4.8"  # 当前: 2.4.8
+    v = "2.4.9"  # 当前: 2.4.9
     return v
 
 
