@@ -98,11 +98,18 @@ def set_query_dc_value(query_dc: (QueryDict, dict), new_dc: dict):
     return query_dc
 
 
-def get_field_names_by_model(model_class):
+def get_field_names_by_model(model_class, field_attr='name'):
+    """
+    获得model.meta中的字段名属性
+
+    :param model_class: 目标模型
+    :param field_attr: 可取[name, verbose_name]
+    :return:
+    """
     if isinstance(model_class, m.QuerySet):
         model_class = get_base_model(model_class)
     fields = model_class._meta.fields
-    field_names = [getattr(field, 'name') for field in fields]
+    field_names = [getattr(field, field_attr) for field in fields]
     return field_names
 
 
